<h1 id="kipoi.get_source">get_source</h1>

```python
get_source(source)
```
Get the source object

__Arguments__

- __source (str)__: source string

__Returns__

`Source child class instance`: like `kipoi.sources.GitLFSSource`

<h1 id="kipoi.list_sources">list_sources</h1>

```python
list_sources()
```
Returns a `pandas.DataFrame` of possible sources

